==> orthanc_1.2.0%2Bdfsg.orig.tar.xz: Orthanc-1.2.0/Core/Images/ImageProcessing.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "ImageAccessor.h"

#include <stdint.h>

namespace Orthanc
{
  class ImageProcessing
  {
  public:
    static void Copy(ImageAccessor& target,
                     const ImageAccessor& source);

    static void Convert(ImageAccessor& target,
                        const ImageAccessor& source);

    static void Set(ImageAccessor& image,
                    int64_t value);

    static void Set(ImageAccessor& image,
                    uint8_t red,
                    uint8_t green,
                    uint8_t blue,
                    uint8_t alpha);

    static void ShiftRight(ImageAccessor& target,
                           unsigned int shift);

    static void GetMinMaxValue(int64_t& minValue,
                               int64_t& maxValue,
                               const ImageAccessor& image);

    static void AddConstant(ImageAccessor& image,
                            int64_t value);

    static void MultiplyConstant(ImageAccessor& image,
                                 float factor);

    static void ShiftScale(ImageAccessor& image,
                           float offset,
                           float scaling);
  };
}

==> orthanc_1.3.1%2Bdfsg.orig.tar.xz: Orthanc-1.3.1/Core/Images/ImageProcessing.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017 Osimis, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "ImageAccessor.h"

#include <stdint.h>

namespace Orthanc
{
  class ImageProcessing
  {
  public:
    static void Copy(ImageAccessor& target,
                     const ImageAccessor& source);

    static void Convert(ImageAccessor& target,
                        const ImageAccessor& source);

    static void Set(ImageAccessor& image,
                    int64_t value);

    static void Set(ImageAccessor& image,
                    uint8_t red,
                    uint8_t green,
                    uint8_t blue,
                    uint8_t alpha);

    static void ShiftRight(ImageAccessor& target,
                           unsigned int shift);

    static void GetMinMaxIntegerValue(int64_t& minValue,
                                      int64_t& maxValue,
                                      const ImageAccessor& image);

    static void GetMinMaxFloatValue(float& minValue,
                                    float& maxValue,
                                    const ImageAccessor& image);

    static void AddConstant(ImageAccessor& image,
                            int64_t value);

    static void MultiplyConstant(ImageAccessor& image,
                                 float factor);

    static void ShiftScale(ImageAccessor& image,
                           float offset,
                           float scaling);

    static void Invert(ImageAccessor& image);
  };
}
